@@ -9,6 +9,7 @@ class TestConfigBase:
     TEST_DIR=None
     TEST_OUTPUT_DIR=None
     PREDICT_CONFIG=None
+    SPLIT_BY_PROB=False
     predictor=None
     def __init__(self):
         if not self.TEST_OUTPUT_DIR:
@@ -28,7 +29,11 @@ def test(cfg):
     for i,f in enumerate(fs):
         img=cv2.imread(f)
         cls,prob=predictor.predict(img)
-        outFolder.openFolder(cls).eat(f)
+
+        if cfg.SPLIT_BY_PROB:
+            outFolder.openFolder(cls).openFolder('%.1f'%(prob)).eat(f)
+        else:
+            outFolder.openFolder(cls).eat(f)
         print(i,f,cls)
         res[f]=[cls,prob]
     return res
